@@ -115,8 +115,15 @@ class ExperimentIterableDataset(IterableDataset):
         # if number_of_batch_rows is provided, batch_size does not matter anymore
 
         if self.authorized:
+            # first used headers from experiment metadata if they were set.
+            headers_ = None
+            if self.experiment_metadata.get("headers"):
+                headers_ = self.experiment_metadata.get("headers")
+            elif self._wml_client is not None:
+                headers_ = self._wml_client._get_headers()
+
             self.connection = FlightConnection(
-                headers=self._wml_client._get_headers() if self._wml_client is not None else self.experiment_metadata.get("headers"),
+                headers=headers_,
                 sampling_type=self.sampling_type,
                 label=self.experiment_metadata.get("prediction_column"),
                 learning_type=self.experiment_metadata.get("prediction_type"),
