@@ -193,6 +193,9 @@ class AutoAI(BaseExperiment):
                   retrain_on_holdout: int = True,
                   categorical_columns: list = None,
                   numerical_columns: list = None,
+                  test_data_csv_separator: Union[List[str], str] = ',',
+                  test_data_excel_sheet: str = None,
+                  test_data_encoding: str = 'utf-8',
                   **kwargs) -> Union['RemoteAutoPipelines', 'LocalAutoPipelines']:
         """
         Initialize an AutoAi optimizer.
@@ -364,6 +367,18 @@ class AutoAI(BaseExperiment):
         numerical_columns: list, optional
             List of columns names that must be treated as numerical.
 
+        test_data_csv_separator: Union[List[str], str], optional
+            The separator, or list of separators to try for separating
+            columns in a CSV user-defined holdout/test file.  Not used if the file_name is not a CSV file.
+            Default is ','.
+
+        test_data_excel_sheet: Union[str, int], optional
+            Name of the excel sheet to use for user-defined holdout/test data. Only use when xlsx file is an test
+            dataset file. By default first sheet is used.
+
+        test_data_encoding: str, optional
+            Encoding type for CSV user-defined holdout/test file.
+
         Returns
         -------
         RemoteAutoPipelines or LocalAutoPipelines, depends on how you initialize the AutoAI object.
@@ -606,6 +621,9 @@ class AutoAI(BaseExperiment):
                 retrain_on_holdout=retrain_on_holdout,
                 numerical_columns=numerical_columns,
                 categorical_columns=categorical_columns,
+                test_data_csv_separator=test_data_csv_separator,
+                test_data_excel_sheet=test_data_excel_sheet,
+                test_data_encoding=test_data_encoding,
                 **reduced_kwargs
             )
             optimizer._workspace = self._workspace
