@@ -205,13 +205,13 @@ class BaseDataConnection(ABC):
             if not self._wml_client.ICP and not self._wml_client.WSD:
                 response = requests.get(
                     self._wml_client.service_instance._href_definitions.get_attachment_href(data_asset_id, attachment_id),
-                    params=self._wml_client.data_assets._client._params(),
-                    headers=self._wml_client.data_assets._client._get_headers())
+                    params=self._wml_client._params(),
+                    headers=self._wml_client._get_headers())
             else:
                 response = requests.get(
                     self._wml_client.service_instance._href_definitions.get_attachment_href(data_asset_id, attachment_id),
-                    params=self._wml_client.data_assets._client._params(),
-                    headers=self._wml_client.data_assets._client._get_headers(),
+                    params=self._wml_client._params(),
+                    headers=self._wml_client._get_headers(),
                     verify=False)
 
             self._wml_client.data_assets._handle_response(200, u'Cannot get attachment details', response)
