@@ -185,6 +185,9 @@ class DataConnection(BaseDataConnection):
         if isinstance(self.location, (AssetLocation, WSDAssetLocation)):
             self.location.wml_client = self.__wml_client
 
+        if getattr(var, 'project_type', None) == 'local_git_storage':
+            self.location.userfs = True
+
     def set_client(self, wml_client):
         """
         Set initialized wml client in connection to enable write/read operations with connection to service.
@@ -295,6 +298,11 @@ class DataConnection(BaseDataConnection):
         except AttributeError:
             _dict['location'] = {}
 
+        # note: convert userfs to string - training service requires it as string
+        if getattr(self.location, 'userfs', False):
+            _dict['location']['userfs'] = str(getattr(self.location, 'userfs', False)).lower()
+        # end note
+
         return _dict
 
     def __repr__(self):
@@ -380,6 +388,12 @@ class DataConnection(BaseDataConnection):
         if _dict.get('id'):
             data_connection.id = _dict['id']
 
+        if _dict['location'].get('userfs'):
+            if str(_dict['location'].get('userfs', 'false')).lower() in ['true', '1']:
+                data_connection.location.userfs = True
+            else:
+                data_connection.location.userfs = False
+
         return data_connection
 
     def _recreate_holdout(
@@ -659,6 +673,10 @@ class DataConnection(BaseDataConnection):
             self.auto_pipeline_params['excel_sheet'] = excel_sheet
         # --- end note
 
+        # note: set default quote character for flight (later applicable only for csv files stored in S3)
+        self.auto_pipeline_params['quote_character'] = 'double_quote'
+        # --- end note
+
         data = DataFrame()
 
         headers = None
@@ -668,6 +686,7 @@ class DataConnection(BaseDataConnection):
                 headers = {'Authorization': f'Bearer {token}'}
         elif impersonate_header is not None:
             headers = self._wml_client._get_headers()
+
             headers['impersonate'] = impersonate_header
 
         if self.type == DataConnectionTypes.S3:
@@ -681,6 +700,13 @@ class DataConnection(BaseDataConnection):
                 is_lib_installed(lib_name='pyarrow', minimum_version='3.0.0', install=True)
 
                 from pyarrow.flight import FlightError
+
+                _iam_id = None
+                if headers and headers.get('impersonate'):
+                    _iam_id = headers.get('impersonate', {}).get('iam_id')
+
+                self._wml_client._iam_id = _iam_id
+                
                 if self._check_if_connection_asset_is_s3():
                     # note: update flight parameters only if `connection_properties` was not set earlier
                     #       (e.x. by wml/autoi)
