@@ -291,8 +291,14 @@ class FlightConnection:
                                               _type='Bearer')
 
         elif 'Basic' in self.headers.get('Authorization', ''):
-            return TokenClientAuthHandler(token=self.headers.get('Authorization', 'Basic  ').split('Basic ')[-1],
-                                          _type='Basic')
+            if "impersonate" in self.headers:
+                authorization_header = self.headers.get('Authorization', 'Basic  ')
+                impersonate_header = self.headers.get('impersonate')
+                auth_json_str = json.dumps(dict(authorization=authorization_header, impersonate=impersonate_header))
+                return TokenClientAuthHandler(token=auth_json_str, _type='json_string', impersonate=True)
+            else:
+                return TokenClientAuthHandler(token=self.headers.get('Authorization', 'Basic  ').split('Basic ')[-1],
+                                              _type='Basic')
 
         else:
             return TokenClientAuthHandler(token=self.headers.get('Authorization'), _type='Bearer')
@@ -337,6 +343,15 @@ class FlightConnection:
                             flight.FlightDescriptor.for_command(source_command)
                         )
                         yield info.endpoints
+                elif 'The property [quote_character]' in str(e):
+                    # Don't sent quote_character in flight command if it is not yet supported and try again.
+                    self.params['quote_character'] = None
+                    for source_command in self._select_source_command():
+                        info = self.flight_client.get_flight_info(
+                            flight.FlightDescriptor.for_command(source_command)
+                        )
+                        yield info.endpoints
+
                 else:
                     raise WrongLocationProperty(reason=str(e))
 
@@ -863,13 +878,21 @@ class FlightConnection:
             command = {"interaction_properties": {'write_mode': "write_raw"}}
 
         else:
+            # limitation for number of rows passed within one mini batch
+            # from flight service (can be between 100 and 10000)
+            # need to test performance with big data
+            default_batch_size = 10000
+            # when reading binary batches, default row is one value of 32k.
+            # If we keep a large default batch size like 10k, we end up with
+            # batches of 300MB being read and kept in memory as 10k chunks
+            # of 32k. This clutters the memory and is more work for GC.
+            # Defaulting to 1000 when reading binary to decrease footprint.
+            if self.read_binary:
+                default_batch_size = 1000
             # when dataset is small we received empty dfs, it is ok (4 is optimum for larger than 1 GB)
             command = {
                 "num_partitions": self.max_flight_batch_number if self.max_flight_batch_number is not None else DEFAULT_PARTITIONS_NUM,
-                # limitation for number of rows passed within one mini batch
-                # from flight service (can be between 100 and 10000)
-                # need to test performance with big data
-                "batch_size": 10000,
+                "batch_size": default_batch_size,
                 "interaction_properties": {}
             }
 
@@ -937,7 +960,7 @@ class FlightConnection:
 
         # Git based project assets property
         if self.data_location is not None and self.data_location['location'].get('userfs'):
-            command['interaction_properties'].update({'userfs': True})
+            command.update({'userfs': True})
 
         if 'path' in command['interaction_properties']:
             command['interaction_properties']['file_name'] = command['interaction_properties']['path']
