@@ -158,8 +158,8 @@ class Script(WMLResource):
     def _create_asset(self, script_meta, file_path, extension='.py'):
 
         ##Step1: Create a data asset
-        f = {'file': open(file_path, 'rb')}
         name = script_meta['metadata'][u'name']
+        f = {'file': (name, open(file_path, 'rb'), 'application/octet-stream')}
 
         if script_meta['metadata'].get('description') is not None:
             desc = script_meta['metadata'][u'description']
