@@ -135,8 +135,8 @@ class Shiny(WMLResource):
     def _create_asset(self, shiny_meta, file_path):
 
         ##Step1: Create a shiny asset
-        f = {'file': open(file_path, 'rb')}
         name = shiny_meta[u'name']
+        f = {'file': (name, open(file_path, 'rb'), 'application/octet-stream')}
 
         if shiny_meta.get('description') is not None:
             desc = shiny_meta[u'description']
