@@ -57,7 +57,8 @@ __all__ = [
     'InvalidImputationParameterNonTS',
     'InvalidImputationParameterTS',
     'InconsistentImputationListElements',
-    'ImputationListNotSupported'
+    'ImputationListNotSupported',
+    'MissingEstimatorForExistingBatchedEstimator'
 ]
 
 #  (C) Copyright IBM Corp. 2021.
@@ -407,3 +408,10 @@ class ImputationListNotSupported(WMLClientError, ValueError):
 class InvalidSamplingType(WMLClientError, ValueError):
     def __init__(self, sampling_type: str, predcition_type: str):
         WMLClientError.__init__(self, f"Sampling type for {sampling_type} is invalid for prediction type {predcition_type}.")
+
+
+class MissingEstimatorForExistingBatchedEstimator(WMLClientError, ValueError):
+    def __init__(self, batched_estimator: str, missing_estimator: str):
+        WMLClientError.__init__(self, f"There is no corresponding estimator in `include_only_estimators` list for " +
+                                f"{batched_estimator} estimator in `include_batched_ensemble_estimators` list. " +
+                                f"Add {missing_estimator} estimator to `include_only_estimators` list.")
